@@ -65,11 +65,12 @@ forecast.hybridModel <- function(object, # nolint
                                  fan = FALSE,
                                  PI.combination = c("extreme", "mean"), # nolint
                                  ...) {
-
-  chkDots(...)
   # Check inputs
+  # Although chkDots() has an `allowed` argument, in R 4.3.3 it is still not implemented.
+  # If it is implemented in a later version, we can probably enable
+  # the check. chkDots(..., allowed = "npaths")
   if (!is.hybridModel(object)) {
-    stop("The object must be constructed from hybridModel().")
+    stop("The object must be constructed from hybridModel().", call. = FALSE)
   }
 
   # apply nrow(xreg) to h if h isn't provided and xreg is
@@ -80,24 +81,24 @@ forecast.hybridModel <- function(object, # nolint
   # xreg should be a matrix and have same number of observations as the horizon
   if (!is.null(xreg)) {
     if (!is.matrix(xreg) && !is.numeric(xreg) && !is.data.frame(xreg)) {
-      stop("The supplied xreg must be numeric, matrix, or data.frame.")
+      stop("The supplied xreg must be numeric, matrix, or data.frame.", call. = FALSE)
     }
     xreg <- as.matrix(xreg)
     if (!is.numeric(xreg)) {
-      stop("The supplied xreg must be numeric.")
+      stop("The supplied xreg must be numeric.", call. = FALSE)
     }
     if (is.null(h) || nrow(xreg) != h) {
-      warning("The number of rows in xreg should match h. Setting h to nrow(xreg).")
+      warning("The number of rows in xreg should match h. Setting h to nrow(xreg).", call. = FALSE)
       h <- nrow(xreg)
     }
   }
 
   # Check the forecast horizon
   if (!is.numeric(h)) {
-    stop("The forecast horizon h must be a positive integer.")
+    stop("The forecast horizon h must be a positive integer.", call. = FALSE)
   }
   if (!as.logical((h %% 1L == 0L)) || h <= 0L) {
-    stop("The forecast horizon h must be a positive integer.")
+    stop("The forecast horizon h must be a positive integer.", call. = FALSE)
   }
 
   # Allow for fan prediction intervals
@@ -107,7 +108,7 @@ forecast.hybridModel <- function(object, # nolint
     if (min(level) > 0 && max(level) < 1) {
       level <- 100 * level
     } else if (min(level) < 0 || max(level) > 99.99) {
-      stop("Prediction interval out of range")
+      stop("Prediction interval out of range", call. = FALSE)
     }
   }
 
@@ -124,7 +125,7 @@ forecast.hybridModel <- function(object, # nolint
     xregA <- xreg
     if (!object$xreg$auto.arima) {
       xregA <- NULL
-      }
+    }
     forecasts$auto.arima <- forecast(object$auto.arima, h = h, xreg = xregA, level = level, ...) # nolint
     forecasts$pointForecasts[, "auto.arima"] <- forecasts$auto.arima$mean
   }
@@ -133,8 +134,8 @@ forecast.hybridModel <- function(object, # nolint
     forecasts$pointForecasts[, "ets"] <- forecasts$ets$mean
   }
   if ("thetam" %in% includedModels) {
-     forecasts$thetam <- forecast(object$thetam, h = h, level = level, ...)
-     forecasts$pointForecasts[, "thetam"] <- forecasts$thetam$mean
+    forecasts$thetam <- forecast(object$thetam, h = h, level = level, ...)
+    forecasts$pointForecasts[, "thetam"] <- forecasts$thetam$mean
   }
   if ("nnetar" %in% includedModels) {
     # Only apply the xreg if it was used in the original model
@@ -163,6 +164,10 @@ forecast.hybridModel <- function(object, # nolint
     forecasts$snaive <- snaive(object$x, h = h, level = level, ...)
     forecasts$pointForecasts[, "snaive"] <- forecasts$snaive$mean
   }
+  if ("arfima" %in% includedModels) {
+    forecasts$arfima <- forecast(object$arfima, h = h, level = level, ...)
+    forecasts$pointForecasts[, "arfima"] <- forecasts$arfima$mean
+  }
 
   # Apply the weights to the individual forecasts and create the final point forecast
   finalForecast <- rowSums(forecasts$pointForecast * weightsMatrix)
@@ -177,7 +182,7 @@ forecast.hybridModel <- function(object, # nolint
   fitsWeightsMatrix <- matrix(rep(forecastWeights, times = nrow(fits)),
                               nrow = nrow(fits), byrow = TRUE)
   fits <- rowSums(fits * fitsWeightsMatrix)
-  resid <- object$x - fits
+  resids <- object$x - fits
 
   # Construct the prediction intervals
   if (PI) {
@@ -189,46 +194,46 @@ forecast.hybridModel <- function(object, # nolint
       upperFunction <- max
       lowerFunction <- min
     }
-     nint <- length(level)
-     upper <- lower <- matrix(NA, ncol = nint, nrow = length(finalForecast))
+    nint <- length(level)
+    upper <- lower <- matrix(NA, ncol = nint, nrow = length(finalForecast))
 
-     piModels <- object$models
-     # Produce each upper/lower limit
-     for (i in 1:nint) {
-        # Produce the upper/lower limit for each model for a given level
-        tmpUpper <- tmpLower <- matrix(NA, nrow = h, ncol = length(piModels))
-        j2 <- 1
-        for (mod in piModels) {
-           tmpUpper[, j2] <- as.numeric(matrix(forecasts[[mod]]$upper, nrow = h)[, i])
-           tmpLower[, j2] <- as.numeric(matrix(forecasts[[mod]]$lower, nrow = h)[, i])
-           j2 <- j2 + 1
-        }
-        # Apply the function for reconciling the prediction intervals
-        upper[, i] <- apply(tmpUpper, 1, FUN = upperFunction)
-        lower[, i] <- apply(tmpLower, 1, FUN = lowerFunction)
-     }
-     if (!is.finite(max(upper)) || !is.finite(min(lower))) {
-        warning("Prediction intervals are not finite.")
-     }
-     colnames(lower) <- colnames(upper) <- paste0(level, "%")
-     forecasts$lower <- lower
-     forecasts$upper <- upper
+    piModels <- object$models
+    # Produce each upper/lower limit
+    for (i in 1:nint) {
+      # Produce the upper/lower limit for each model for a given level
+      tmpUpper <- tmpLower <- matrix(NA, nrow = h, ncol = length(piModels))
+      j2 <- 1
+      for (mod in piModels) {
+        tmpUpper[, j2] <- as.numeric(matrix(forecasts[[mod]]$upper, nrow = h)[, i])
+        tmpLower[, j2] <- as.numeric(matrix(forecasts[[mod]]$lower, nrow = h)[, i])
+        j2 <- j2 + 1
+      }
+      # Apply the function for reconciling the prediction intervals
+      upper[, i] <- apply(tmpUpper, 1, FUN = upperFunction)
+      lower[, i] <- apply(tmpLower, 1, FUN = lowerFunction)
+    }
+    if (!is.finite(max(upper)) || !is.finite(min(lower))) {
+      warning("Prediction intervals are not finite.", call. = FALSE)
+    }
+    colnames(lower) <- colnames(upper) <- paste0(level, "%")
+    forecasts$lower <- lower
+    forecasts$upper <- upper
   }
   forecasts$mean <- finalForecast
 
   # Add the fitted and residuals values
   if (is.ts(object$x)) {
     fits <- ts(fits)
-    resid <- ts(resid)
-    tsp(fits) <- tsp(resid) <- tsp(object$x)
+    resids <- ts(resids)
+    tsp(fits) <- tsp(resids) <- tsp(object$x)
   }
   forecasts$fitted <- fits
-  forecasts$residuals <- resid
+  forecasts$residuals <- resids
 
   # Build a forecast object
   forecasts$x <- forecasts[[object$models[1]]]$x
   forecasts$method <- paste0(object$models, " with weight ", round(object$weights, 3))
   forecasts$level <- level
   class(forecasts) <- "forecast"
-  return(forecasts)
+  forecasts
 }
